@@ -15,7 +15,7 @@
 #'
 #' @param A (Tensor): tensor of shape `(*, n)` or `(*, m, n)` where `*` is zero or more batch dimensions
 #' @param ord (int, float, inf, -inf, 'fro', 'nuc', optional): order of norm. Default: `NULL`
-#' @param dim (int, Tuple[int], optional): dimensions over which to compute
+#' @param dim (int, `Tuple[int]`, optional): dimensions over which to compute
 #'   the vector or matrix norm. See above for the behavior when `dim=NULL`.
 #'   Default: `NULL`
 #' @param keepdim (bool, optional): If set to `TRUE`, the reduced dimensions are retained
@@ -264,7 +264,7 @@ linalg_cond <- function(A, p = NULL) {
 #' @family linalg
 #' @export
 linalg_matrix_rank <- function(A, ..., atol = NULL, rtol = NULL, tol = NULL, hermitian = FALSE) {
-  ellipsis::check_dots_empty()
+  rlang::check_dots_empty()
   if (!is.null(tol)) {
     warn("`tol` argument is deprecated in favor of `atol` and `rtol`.")
     atol <- tol
@@ -833,7 +833,7 @@ linalg_solve <- function(A, B) {
 #' @family linalg
 #' @export
 linalg_lstsq <- function(A, B, rcond = NULL, ..., driver = NULL) {
-  ellipsis::check_dots_empty()
+  rlang::check_dots_empty()
 
   args <- list(
     self = A,
@@ -1135,7 +1135,7 @@ linalg_tensorinv <- function(A, ind = 3L) {
 #'
 #' @param A (Tensor): tensor to solve for.
 #' @param B (Tensor): the solution
-#' @param dims (Tuple[int], optional): dimensions of `A` to be moved.
+#' @param dims (`Tuple[int]`, optional): dimensions of `A` to be moved.
 #' If `NULL`, no dimensions are moved. Default: `NULL`.
 #'
 #' @examples
@@ -1246,6 +1246,6 @@ linalg_inv_ex <- function(A, check_errors = FALSE) {
 #' @family linalg
 #' @export
 linalg_solve_triangular <- function(A, B, ..., upper, left = TRUE, unitriangular = FALSE) {
-  ellipsis::check_dots_empty()
+  rlang::check_dots_empty()
   torch_linalg_solve_triangular(A, B, upper, left, unitriangular)
 }
